# -*- coding: utf-8 -*-
import itertools
import tempfile
from pathlib import Path

import tomli
import typer
import wakepy
from rich.console import Console

toml = Path("/Users/evanbaird/Projects/Learning/wakeypy/pyproject.toml")


with toml.open(mode="rb") as fp:
    config = tomli.load(fp)


console = Console()


def version_callback(value: bool):
    """
    Version callback.
    """
    if value:
        print(f"Awesome CLI Version: {config['project']['version']} ")
        raise typer.Exit()


def nulling():
    """This function will create an inifinite loop"""
    for _ in itertools.count(1):
        temp = tempfile.TemporaryFile()
        temp.write(b"YARP!")
        temp.close()


def keep_presenting():
    """This function will run keep presenting."""
    try:
        with console.status(
            "[italic green]Staying AWAKE![/] [bold][Press Ctrl+C to exit][/] :sleepy:",
            spinner="smiley",
        ):
            with wakepy.keep.presenting():
                nulling()

    except KeyboardInterrupt:
        console.print("[bold red]Exited[/] :tired_face:")


def keep_returning():
    """This function will run keep returning."""
    try:
        with console.status(
            "[italic red]Staying AWAKE![/] [bold][Press Ctrl+C to exit][/] :dizzy_face:",
            spinner="clock",
        ):
            with wakepy.keep.running():
                nulling()

    except KeyboardInterrupt:
        console.print("[bold red]Exited[/] :drooling_face:")



# -*- coding: utf-8 -*-
"""
Text Print
"""
from art import tprint
from rich.console import Console

console = Console()


def running_programs():
    """
    This will have the text print with the checkmark(X) for "System will continue running".
    """
    tprint("WakeyPy!!!")
    console.print("[green]v.0.1.0")
    print()
    console.print(
        ":white_check_mark: [blue]System will continue running programs.",
    )
    console.print(
        ":x: [strike]Display is kept on and automatic screenlock disabled.[/]",
    )
    print()


def running_presenting():
    """
    This will have system continue running programs AND have screenlock disabled.
    """
    tprint("WakeyPy!!!")
    console.print("[green]v.0.1.0")
    print()
    console.print(
        ":white_check_mark: [bold blue]System will continue running programs.",
    )
    console.print(
        ":white_check_mark: [bold blue]Display is kept on and automatic screenlock disabled.[/]",
    )
    print()



# -*- coding: utf-8 -*-
from typing import Annotated, Optional

import typer

from .functions import keep_presenting, keep_returning, version_callback
from .text_print import running_presenting, running_programs

app = typer.Typer()


# Create -h short name
CONTEXT_SETTING = dict(help_option_names=["-h", "--help"])


@app.command(context_settings=CONTEXT_SETTING)
def main(
    running: Annotated[
        bool,
        typer.Option(
            "-r",
            "--keep-running",
            help="Keep programs running (DEFAULT); inhibit automatic",
            metavar="🥱",
        ),
    ] = False,
    presenting: Annotated[
        bool,
        typer.Option(
            "-p",
            "--keep-presenting",
            help="Display is kept on and automatic screenlock disabled.",
            metavar="😵",
        ),
    ] = False,
    version: Annotated[
        Optional[bool],
        typer.Option(
            "-v",
            "--version",
            callback=version_callback,
            is_eager=True,
            help="Print out version and exit.",
        ),
    ] = None,
) -> None:
    """
    Wakepy CLI clone.
    """
    if presenting:
        running_presenting()
        keep_presenting()

    elif running:
        running_programs()
        keep_returning()

    else:
        running_programs()
        keep_returning()


if __name__ == "__main__":
    app()
